@@ -7,7 +7,7 @@ def create_project(project_name):
 
     ## try to create the project folder
     try:
-        os.mkdir('apscale_{}'.format(project_name))
+        os.mkdir('{}_apscale'.format(project_name))
     except FileExistsError:
         print('A project with that name already exists. Try another name.')
         return None
@@ -21,9 +21,11 @@ def create_project(project_name):
                   '6_dereplication_pooling/data/dereplication',
                   '6_dereplication_pooling/data/pooling',
                   '7_otu_clustering/data',
-                  '8_denoising/data']
+                  '8_denoising/data',
+                  '9_lulu_filtering/otu_clustering/data',
+                  '9_lulu_filtering/denoising/data']
 
-    subfolders = [Path(project_name).joinpath(subfolder) for subfolder in subfolders]
+    subfolders = [Path('{}_apscale'.format(project_name)).joinpath(subfolder) for subfolder in subfolders]
 
     for folder in subfolders:
         os.makedirs(folder)
@@ -31,9 +33,9 @@ def create_project(project_name):
     ## generate and then populate the settings file
     wb = openpyxl.Workbook()
     ws = wb.active
-    wb.save(Path(project_name).joinpath('Settings.xlsx'))
-    wb = openpyxl.load_workbook(Path(project_name).joinpath('Settings.xlsx'))
-    writer = pd.ExcelWriter(Path(project_name).joinpath('Settings.xlsx'), engine = 'openpyxl')
+    wb.save(Path('{}_apscale'.format(project_name)).joinpath('Settings.xlsx'))
+    wb = openpyxl.load_workbook(Path('{}_apscale'.format(project_name)).joinpath('Settings.xlsx'))
+    writer = pd.ExcelWriter(Path('{}_apscale'.format(project_name)).joinpath('Settings.xlsx'), engine = 'openpyxl')
     writer.book = wb
     del wb['Sheet']
 
@@ -69,19 +71,25 @@ def create_project(project_name):
 
 
     ## write the 7_otu_clustering sheet
-    df_7 = pd.DataFrame([[97]],
-                        columns = ['pct id'])
+    df_7 = pd.DataFrame([[97, 'True']],
+                        columns = ['pct id', 'to excel'])
 
     df_7.to_excel(writer, sheet_name = '7_otu_clustering', index = False)
 
     ## write the 8_denoising sheet
-    df_8 = pd.DataFrame([[2, 8]],
-                        columns = ['alpha', 'minsize'])
+    df_8 = pd.DataFrame([[2, 8, 'True']],
+                        columns = ['alpha', 'minsize', 'to excel'])
 
     df_8.to_excel(writer, sheet_name = '8_denoising', index = False)
 
+    ## write the 8_denoising sheet
+    df_9 = pd.DataFrame([[84, 95, 1, 'True']],
+                        columns = ['minimum similarity', 'minimum relative cooccurence', 'minimum ratio', 'to excel'])
+
+    df_9.to_excel(writer, sheet_name = '9_lulu_filtering', index = False)
+
     ## save the Settings file againg
-    wb.save(Path(project_name).joinpath('Settings.xlsx'))
+    wb.save(Path('{}_apscale'.format(project_name)).joinpath('Settings.xlsx'))
     writer.close()
 
     ## give user output
